<?php

namespace Drupal\readmore_extrafield\Plugin\ExtraField\Display;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\extra_field_plus\Plugin\ExtraFieldPlusDisplayFormattedBase;
use Drupal\Core\Url;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Example Extra field Display.
 *
 * @ExtraFieldDisplay(
 *   id = "readmore_extrafield",
 *   label = @Translation("Read more"),
 *   description = @Translation("Link to the entity"),
 *   bundles = {
 *     "node.*"
 *   },
 *   weight = 100
 * )
 */
class ReadmoreExtrafield extends ExtraFieldPlusDisplayFormattedBase {
  use StringTranslationTrait;

  /**
   * {@inheritdoc}
   */
  public function viewElements(ContentEntityInterface $entity){
    $settings = $this->getSettings();
    $link_title = !empty($settings['link_title']) ? $settings['link_title'] : $this->t('Read more');
    $element = [
      '#theme' => 'readmore_extrafield',
      '#title' => $link_title,
      '#url' => Url::fromRoute('entity.node.canonical', [
        'node' => $entity->id(),
      ]),
      '#attributes' => [
        'class' => [
          'readmore-extrafield-link'
        ]
      ]
    ];
    return $element;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsForm(){
    $form = parent::settingsForm();

    $form['link_title'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Label'),
      '#description' => $this->t('The label of the read on hyperlink.'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function defaultFormValues(){
    $values = parent::defaultFormValues();

    $values += [
      'link_title' => $this->t('Read more'),
    ];

    return $values;
  }
}
